@@ -17,13 +17,13 @@
 ;;; array of gen -> vector (and setf aref to vector-set! in this case)
 ;;; nil -> #f, t -> #t
 ;;; incf, decf to explicit sets
-;;; length sometimes length, length etc
+;;; length sometimes length, vector-length etc
 ;;; make-filter in scm requires coeffs arrays
 ;;; &optional, &key -> define*
 ;;; two-pi -> (* 2 pi)
 ;;; open-input and close-input -> make-readin or use name directly (in make-readin)
 ;;; make-locsig channel arg is in a different place
-;;; progn -> begin, when -> if+begin (prog1 prog2), dotimes -> do
+;;; progn -> begin, dotimes -> do
 ;;; string= -> string=? (also string-equal)
 ;;; integerp -> integer? and others like it (null -> null? is the tricky one)
 ;;; sound-duration -> mus-sound-duration and similarly for others
@@ -139,10 +139,13 @@
   (let ((start (seconds->samples beg))
 	(end (seconds->samples (+ beg dur)))
 	(freqs (make-float-vector 20)))
-    (let ((obank (make-oscil-bank freqs (make-float-vector 20 0.0))))
-      (do ((i 0 (+ i 1)))
-	  ((= i 20))
-	(set! (freqs i) (hz->radians (* (+ i 1) 100))))
+    (let ((obank (make-oscil-bank freqs 
+				  (let ((fv (make-float-vector 20 0.0)))
+				    (do ((i 0 (+ i 1)))
+					((= i 20) fv)
+				      (set! (freqs i) (hz->radians (* (+ i 1) 100)))))
+				  (make-float-vector 20 1.0)
+				  #t)))
       (set! amp (* 0.05 amp))
       (do ((i start (+ i 1))) 
 	  ((= i end))
@@ -243,7 +246,7 @@
 					;(define w1 (make-polyshape :frequency 100.0 
 					;			   :partials (let ((frqs ()))
 					;				       (do ((i 1 (+ i 1)))
-					;					   ((= i 10) (begin (format #t frqs) (reverse frqs)))
+					;					   ((= i 10) (begin (format () frqs) (reverse frqs)))
 					;					 (set! frqs (cons (/ 1.0 (* i i)) (cons i frqs)))))))
 
 (define (simple-poly beg dur freq amp)
@@ -501,12 +504,7 @@
 	  ((= i end))
 	(outa i (* amp (src sr)))))))
 
-(define (simple-sr2a beg dur amp speed file)
-  (let ((start (seconds->samples beg))
-	(end (seconds->samples (+ beg dur)))
-	(sr (make-src :input (make-readin file) :srate speed)))
-    (do ((i start (+ i 1))) ((= i end))
-      (outa i (* amp (src sr))))))
+(define simple-sr2a simple-src)
 
 (define (simple-sro beg dur amp speed freq)
   (let ((os (make-oscil freq)))
@@ -552,8 +550,8 @@
 	    (do ((i start (+ i 1))) ((= i end))
 	      (outa i (* ampa (ina i *reverb*))))
 	    (do ((i start (+ i 1))) ((= i end))
-	      (if (> ampa 0.0) (outa i (* ampa (ina i *reverb*))))
-	      (if (> ampb 0.0) (outb i (* ampb (inb i *reverb*)))))))))
+	      (outa i (* ampa (ina i *reverb*)))
+	      (outb i (* ampb (inb i *reverb*))))))))
 
 (define (simple-f2s beg dur amp file)
   (let ((start (seconds->samples beg))
@@ -562,14 +560,9 @@
     (do ((i start (+ i 1))
 	 (ctr 0 (+ ctr 1)))
 	((= i end))
-      (outa i (* amp (file->sample fil ctr 0))))))
+      (outa i (* amp (file->sample fil ctr))))))
 
-(define (simple-rdf beg dur amp file)
-  (let ((rd (make-readin file))
-	(start (seconds->samples beg))
-	(end (seconds->samples (+ beg dur))))
-    (do ((i start (+ i 1))) ((= i end))
-      (outa i (* amp (readin rd))))))
+(define simple-rdf simple-rd)
 
 (define (simple-loc beg dur freq amp)
   (let ((os (make-oscil freq))
@@ -619,8 +612,8 @@
     (do ((i start (+ i 1))) ((= i end))
       (let ((amp .3)
 	    (j 4))
-	(if (not (= j 4)) (format #t "local j is ~D\n" j))
-	(if (> (abs (- amp .3)) .001) (format #t "local amp is ~F\n" amp)))
+	(if (not (= j 4)) (format () "local j is ~D\n" j))
+	(if (> (abs (- amp .3)) .001) (format () "local amp is ~F\n" amp)))
       (if (= j 2)
 	  (outa i (* amp (oscil os)))))))
 
@@ -632,11 +625,11 @@
 	(start (seconds->samples beg))
 	(end (seconds->samples (+ beg dur))))
     (do ((i start (+ i 1))) ((= i end))
-      (if (not (= j 2199023256786)) (format #t "local j is ~A" j))
-      (if (not (= jj -1099511632097)) (format #t "local jj is ~A" jj))
+      (if (not (= j 2199023256786)) (format () "local j is ~A" j))
+      (if (not (= jj -1099511632097)) (format () "local jj is ~A" jj))
       (if (= mj -3)
 	  (outa i (* amp (oscil os)))
-	  (format #t "minus 3: ~D" mj)))))
+	  (format () "minus 3: ~D" mj)))))
 
 (define (sample-desc beg dur freq amp)
   (let ((os (make-oscil freq))
@@ -647,9 +640,9 @@
       (if (not printed)
 	  (begin
 	    (if (not (string=? (mus-describe os) "oscil freq: 440.000Hz, phase: 0.000"))
-		(format #t "describe oscil: ~A~%" (mus-describe os)))
+		(format () "describe oscil: ~A~%" (mus-describe os)))
 	    (if (> (abs (- (mus-frequency os) freq)) .001)
-		(format #t "osc freq: ~A (~A)~%" (mus-frequency os) freq))
+		(format () "osc freq: ~A (~A)~%" (mus-frequency os) freq))
 	    (set! printed #t)))
       (outa i (* amp (oscil os))))))
 
@@ -657,16 +650,15 @@
   (let ((table-size 256))
     (let ((start (seconds->samples beg))
 	  (end (seconds->samples (+ beg dur)))
-	  (j 0)
 	  (buf (make-table-lookup freq 0.0 :size table-size)))
       (let ((table (mus-data buf)))
 	(do ((i 0 (+ i 1)))
 	    ((= i table-size))
 	  (set! (table i) (/ i table-size))))
-      (do ((i start (+ i 1))) ((= i end))
-	(outa i (* amp ((mus-data buf) j) (table-lookup buf)))
-	(set! j (+ j 1))
-	(if (>= j table-size) (set! j 0))))))
+      (do ((i start (+ i 1))
+	   (j 0 (modulo (+ j 1) table-size)))
+	  ((= i end))
+	(outa i (* amp ((mus-data buf) j) (table-lookup buf)))))))
 
 (define (sample-xtab beg dur freq amp)
   (let ((start (seconds->samples beg))
@@ -785,7 +777,7 @@
 				:fft-size size
 				:edit (lambda (pv)
 					(if (not (= (mus-location pv) 0))
-					    (format #t "outctr: ~A" (mus-location pv)))
+					    (format () "outctr: ~A" (mus-location pv)))
 					#t))))
       (do ((i start (+ i 1))) ((= i end))
 	(outa i (* amp (phase-vocoder sr))))))
@@ -829,7 +821,7 @@
 	    (begin
 	      (set! (mus-frequency g) frq)
 	      (if (> (abs (- (mus-frequency g) frq)) .001)
-		  (format #t "oops ~A ~A" (mus-frequency g) frq))
+		  (format () "oops ~A ~A" (mus-frequency g) frq))
 	      (do ((k start (+ k 1))) 
 		  ((= k end))
 		(outa k (* amp (oscil g))))))))))
@@ -849,10 +841,10 @@
       (do ((i 0 (+ i 1)))
 	  ((= i (length phases)))
 	(set! (phases i) (+ (phases i) (freqs i))))
-      (if (not (= (ints 0) 32)) (format #t "int array trouble"))
+      (if (not (= (ints 0) 32)) (format () "int array trouble"))
       (set! (ints 1) 3)
-      (if (not (= (ints 1) 3)) (format #t "set int array trouble"))
-      (if (not (= (length amps) 3)) (format #t "amps len: ~A" (length amps)))
+      (if (not (= (ints 1) 3)) (format () "set int array trouble"))
+      (if (not (= (length amps) 3)) (format () "amps len: ~A" (length amps)))
       (outa i (clm23-sine-bank amps phases 3)))))
 
 (define (sample-flt beg dur freq amp)
@@ -870,13 +862,13 @@
       (let ((xs (mus-xcoeffs flt)))
 	(if (or (> (abs (- (xs 1) (mus-xcoeff flt 1))) .001)
 		(> (abs (- (xs 1) 0.0625)) .001))
-	    (format #t "~A ~A~%" (xs 1) (mus-xcoeff flt 1))))
+	    (format () "~A ~A~%" (xs 1) (mus-xcoeff flt 1))))
       (let ((data (mus-data flt)))
-	(if (> (data 0) 1.0) (format #t "data overflow? ~A~%" (data 0))))
+	(if (> (data 0) 1.0) (format () "data overflow? ~A~%" (data 0))))
       (let ((is intdat)
 	    (fs fltdat))
-	(if (not (= (is 1) 3)) (format #t "intdat let: ~A~%" (is 1)))
-	(if (> (abs (- (fs 1) 3.14)) .001) (format #t "fltdat let: ~A~%" (fs 1))))
+	(if (not (= (is 1) 3)) (format () "intdat let: ~A~%" (is 1)))
+	(if (> (abs (- (fs 1) 3.14)) .001) (format () "fltdat let: ~A~%" (fs 1))))
       (outa i (* amp (filter flt (oscil os)))))))
 
 (define (sample-arrintp beg dur freq amp)
@@ -885,15 +877,15 @@
 	  (arr (make-float-vector 101))
 	  (start (seconds->samples beg))
 	  (end (seconds->samples (+ beg dur)))
-	  (loc 0.0)
 	  (loc-incr (/ 100.0 len)))
       (do ((i 0 (+ i 1))
 	   (x 0.0 (+ x .01)))
 	  ((= i 100))
 	(set! (arr i) x))
-      (do ((i start (+ i 1))) ((= i end))
-	(outa i (* amp (array-interp arr loc) (oscil os)))
-	(set! loc (+ loc loc-incr))))))
+      (do ((i start (+ i 1))
+	   (loc 0.0 (+ loc loc-incr)))
+	  ((= i end))
+	(outa i (* amp (array-interp arr loc) (oscil os)))))))
 
 (define (sample-if beg dur freq amp)
   (let ((os (make-oscil freq))
@@ -903,63 +895,55 @@
 	(j 0)
 	(bool #t))
     (do ((i start (+ i 1))) ((= i end))
-      (if (and (= i start) (not (= k -123))) (format #t "init k: ~A~%" k))
-      (if (not bool) (format #t "bool: ~A~%" bool))
+      (if (and (= i start) (not (= k -123))) (format () "init k: ~A~%" k))
+      (if (not bool) (format () "bool: ~A~%" bool))
       (set! j (if bool 1 2))
-      (if (not (= j 1)) (format #t "if expr: ~A~%" j))
-      (if bool (set! j 3) (set! j 4))
-      (if (not (= j 3)) (format #t "if statement: ~A~%" j))
+      (if (not (= j 1)) (format () "if expr: ~A~%" j))
+      (set! j (if bool 3 4))
+      (if (not (= j 3)) (format () "if statement: ~A~%" j))
       (if (integer? k) (set! j 5))
-      (if (not (= j 5)) (format #t "int k? ~A ~A~%" (integer? k) j))
+      (if (not (= j 5)) (format () "int k? ~A ~A~%" (integer? k) j))
       (if (= j k) (set! j 6))
-      (if (= j 6) (format #t "j if false: ~A~%" j))
-      (set! j (if (= j k) (+ k 7) (+ k 8)))
-      (if (not (= j (+ k 8))) (format #t "if false expr: ~A ~A~%" j k))
+      (if (= j 6) (format () "j if false: ~A~%" j))
+      (set! j (+ k (if (= j k) 7 8)))
+      (if (not (= j (+ k 8))) (format () "if false expr: ~A ~A~%" j k))
       (set! j (if (> j -1234) (if (> k -1234) 9 10) 11))
-      (if (not (= j 9)) (format #t "if 2 expr: ~A~%" j))
+      (if (not (= j 9)) (format () "if 2 expr: ~A~%" j))
       (set! j (if (> j -1234) (begin (set! k 0) 12) 13))
-      (if (not (= j 12)) (format #t "if begin expr: ~A~%" j))
-      (if (> j -1234) (begin (set! j 1234) (set! j 14)) (set! j 15))
-      (if (not (= j 14)) (format #t "if begin: ~A~%" j))
-					;	 (if (> j -1234) (set! j (prog1 16 (set! k 0))))
-					;	 (if (not (= j 16)) (format #t "if prog1: ~A~%" j))
-					;	 (if (> j -1234) (set! j (prog2 (set! k 0) 17 (set! k 0))))
-					;	 (if (not (= j 17)) (format #t "if prog2: ~A~%" j))
-					;       (set! k (loop for j from 1 to 4 sum j))
-					;       (if (not (= k 10)) (format #t "loop sum: ~A~%" k))
-					;	 (if (> j -1234) (set! j (prog2 (set! k 0) (if (> j -1234) (begin (set! k 123) 18) 19) (set! k 0))))
-					;	 (if (not (= j 18)) (format #t "if nested prog2: ~A~%" j))
+      (if (not (= j 12)) (format () "if begin expr: ~A~%" j))
       (set! j 123)
-      (cond ((= j 0) (set! k -1))
-	    ((= j 12) (set! k -2))
-	    ((= j 123) (set! k -3))
-	    (#t (set! k -4)))
-      (if (not (= k -3)) (format #t "cond: ~A ~A~%" j k))
-      (set! k (cond ((= j 0) -4)
-		    ((= j 12) -5)
-		    (#t -6)))
-      (if (not (= k -6)) (format #t "cond expr: ~A ~A~%" j k))
+      (case j
+	((0) (set! k -1))
+	((12) (set! k -2))
+	((123) (set! k -3))
+	(else (set! k -4)))
+      (if (not (= k -3)) (format () "cond: ~A ~A~%" j k))
+      (set! k (case j
+		((0) -4)
+		((12) -5)
+		(else -6)))
+      (if (not (= k -6)) (format () "cond expr: ~A ~A~%" j k))
       (set! k (let ((a 123))
 		(if (> a 0)
 		    20
 		    32)))
-      (if (not (= k 20)) (format #t "let expr: ~A ~A~%" j k))
+      (if (not (= k 20)) (format () "let expr: ~A ~A~%" j k))
       (let ((a 123))
 	(set! k a))
-      (if (not (= k 123)) (format #t "let: ~A ~A~%" j k))
+      (if (not (= k 123)) (format () "let: ~A ~A~%" j k))
       (set! k 123)
       (set! bool (= k 123))
-      (if (not bool) (format #t "bool expr: ~A~%" bool))
+      (if (not bool) (format () "bool expr: ~A~%" bool))
       (set! bool (if (= k 123) (> k 0) (< k 0)))
-      (if (not bool) (format #t "if bool expr: ~A~%" bool))
+      (if (not bool) (format () "if bool expr: ~A~%" bool))
       (set! j 0)
       (set! k (do ((m 0 (+ 1 m)))
 		  ((= m 3) j)
 		(set! j (+ j 1))))
-      (if (not (= k 3)) (format #t "do expr: ~A~%" k))
+      (if (not (= k 3)) (format () "do expr: ~A~%" k))
 					;	 (dotimes (m 2)
 					;		  (set! k (- k 1)))
-					;	 (if (not (= k 1)) (format #t "dotimes: ~A~%" k))
+					;	 (if (not (= k 1)) (format () "dotimes: ~A~%" k))
       (outa i (* amp (oscil os))))))
 
 (define (sample-arrfile beg dur freq amp)
@@ -999,23 +983,9 @@
       (outa i (* amp (granulate sr))))))
 
 					;(with-sound () (simple-grn-f2 0 1 1 2 "oboe.snd"))
-
-(define (simple-grn-f3 beg dur amp speed file)
-  (let ((start (seconds->samples beg))
-	(end (seconds->samples (+ beg dur)))
-	(sr (make-granulate :input (make-readin file) :expansion speed)))
-    (do ((i start (+ i 1))) ((= i end))
-      (outa i (* amp (granulate sr))))))
-
+(define simple-grn-f3 simple-grn-f2)
 					;(with-sound () (simple-grn-f3 0 1 1 2 "oboe.snd"))
-
-(define (simple-grn-f4 beg dur amp speed file)
-  (let ((start (seconds->samples beg))
-	(end (seconds->samples (+ beg dur)))
-	(sr (make-granulate :input (make-readin file) :expansion speed)))
-    (do ((i start (+ i 1))) ((= i end))
-      (outa i (* amp (granulate sr))))))
-
+(define simple-grn-f4 simple-grn-f2)
 					;(with-sound () (simple-grn-f4 0 1 1 2 "oboe.snd"))
 
 (define (simple-grn-f5 beg dur amp speed file)
@@ -1023,7 +993,7 @@
 	(end (seconds->samples (+ beg dur)))
 	(sr (make-granulate :input (make-readin file) 
 			    :expansion speed
-			    :edit (lambda (g) (float-vector-scale! (mus-data g) 2.0) 0.0))))
+			    :edit (lambda (g) (float-vector-scale! (mus-data g) 2.0) 0))))
     (do ((i start (+ i 1))) ((= i end))
       (outa i (* amp (granulate sr))))))
 					;(with-sound (:statistics #t) (simple-grn-f5 0 1 1 2 "oboe.snd"))
@@ -1210,23 +1180,23 @@
       (set! ok1 0.0)
       (if (or e1 e2)
 	  (set! ok1 (+ ok1 (env e1)))
-	  (format #t ";or1 a~%"))
+	  (format () ";or1 a~%"))
       (if (not (or e1 e2))
-	  (format #t ";or1 1~%"))
+	  (format () ";or1 1~%"))
       (if (and e1 e2)
 	  (set! ok1 (+ ok1 (env e2)))
-	  (format #t ";or1 b~%"))
+	  (format () ";or1 b~%"))
       (if (not (and e1 e2))
-	  (format #t ";or1 2~%"))
+	  (format () ";or1 2~%"))
       (if (or e3 e1 e2)
 	  (mus-reset e2) ; resets e2 -> 1.0
-	  (format #t ";or1 c~%"))
+	  (format () ";or1 c~%"))
       (if (and e1 e3 e2)
-	  (format #t ";or1 3~%"))
+	  (format () ";or1 3~%"))
       (if (not e1)
-	  (format #t ";or1 4~%"))
+	  (format () ";or1 4~%"))
       (if (< (abs ok1) .001)
-	  (format #t ";or1 ok1: ~A~%" ok1)))))
+	  (format () ";or1 ok1: ~A~%" ok1)))))
 
 (define (or2)
   (let ((e1 (make-env '(0 0 1 1) :length 10))
@@ -1242,23 +1212,23 @@
       (set! okb #t)
       (if (or e1 e2)
 	  (set! ok1 (+ ok1 (env e1)))
-	  (format #t ";or2 a~%"))
+	  (format () ";or2 a~%"))
       (if (not (or e1 e2 okb))
-	  (format #t ";or2 1~%"))
+	  (format () ";or2 1~%"))
       (if (and e1 e2)
 	  (set! ok1 (+ ok1 (env e2)))
-	  (format #t ";or2 b~%"))
+	  (format () ";or2 b~%"))
       (if (not (and e1 e2))
-	  (format #t ";or2 2~%"))
+	  (format () ";or2 2~%"))
       (if (or e3 e1 e2)
 	  (mus-reset e2) ; resets e2 -> 1.0
-	  (format #t ";or2 c~%"))
+	  (format () ";or2 c~%"))
       (if (and e1 e3 e2)
-	  (format #t ";or2 3~%"))
+	  (format () ";or2 3~%"))
       (if (not e1)
-	  (format #t ";or2 4~%"))
+	  (format () ";or2 4~%"))
       (if (< (abs ok1) .001)
-	  (format #t ";or1 ok1: ~A~%" ok1)))))
+	  (format () ";or1 ok1: ~A~%" ok1)))))
 
 (define (or3)
   (let ((e1 (make-env '(0 0 1 1) :length 10))
@@ -1271,23 +1241,23 @@
     (do ((i 0 (+ i 1)))
 	((= i 1))
       (cond (e1 (set! ok1 (+ ok1 (env e1))))
-	    (#t (format #t ";or3 1~%")))
+	    (#t (format () ";or3 1~%")))
       (if (or f1 f2)
 	  (set! ok1 (+ ok1 (f2 0)))
-	  (format #t ";or3 a~%"))
+	  (format () ";or3 a~%"))
       (if (not (or f2 f1))
-	  (format #t ";or3 2~%"))
+	  (format () ";or3 2~%"))
       (if (and f2 f1)
 	  (set! ok1 (+ ok1 (f1 1)))
-	  (format #t ";or3 b~%"))
+	  (format () ";or3 b~%"))
       (if (or i1 i2)
 	  (set! oki (+ oki (i2 0)))
-	  (format #t ";or3 d~%"))
+	  (format () ";or3 d~%"))
       (if (not (or i2 i1))
-	  (format #t ";or3 3~%"))
+	  (format () ";or3 3~%"))
       (if (and i2 i1)
 	  (set! oki (+ oki (i1 1)))
-	  (format #t ";or3 e~%")))))
+	  (format () ";or3 e~%")))))
 
 (define (or4)
   (let ((e1 (make-env '(0 0 1 1) :length 10))
@@ -1303,18 +1273,15 @@
 	      (and f1 f2)
 	      (and i1 i2))
 	  (set! oki (+ oki 1))
-	  (format #t ";or4 a~%"))
+	  (format () ";or4 a~%"))
       (if (and (or f1 f2)
 	       (not (or i1 i2))
 	       (or e1 e2))
-	  (format #t ";or4 1~%"))
-      (if f1
-	  (if e1
-	      (if (not e2)
-		  (format #t ";or4 2~%")
-		  (set! oki (+ oki 1)))
-	      (format #t ";or4 3~%"))
-	  (format #t ";or4 4~%")))))
+	  (format () ";or4 1~%"))
+      (cond ((not f1) (format () ";or4 4~%"))
+	    ((not e1) (format () ";or4 3~%"))
+	    ((not e2) (format () ";or4 2~%"))
+	    (else (set! oki (+ oki 1)))))))
 
 
 ;;; --------------------------------------------------------------------------------
@@ -1429,7 +1396,7 @@
 	      ((= i n))
 	    (set! (modulators i) (hz->radians (* freq (mc-ratios i) (mod-phases i))))
 	    (set! (fm-indices i) (hz->radians (* freq (indexes i) (mc-ratios i)))))
-	  (let ((ob (make-oscil-bank modulators (make-float-vector n 0.0) fm-indices)))
+	  (let ((ob (make-oscil-bank modulators (make-float-vector n 0.0) fm-indices #t)))
 	    (do ((i start (+ i 1)))
 		((= i end))
 	      (outa i (* amp (oscil cr (oscil-bank ob))))))))))
@@ -1486,7 +1453,7 @@
     (do ((i start (+ i 1))
 	 (x 0.0 (+ x x-incr)))
 	((= i end))
-      (set! y (+ x (* index (sin y)))) ; 2 statements better here than 1 -- opt sees (* s (sin s)) twice
+      (set! y (+ x (* index (sin y))))
       (outa i (* amp (sin y))))))
 
 
@@ -1589,29 +1556,9 @@
 	((= i end))
       (outa i (* amp (oscil os))))))
 
-(define (sndclmdoc-simp-1 beg dur freq amp)
-  (let ((os (make-oscil freq))
-	(start (seconds->samples beg))
-	(end (seconds->samples (+ beg dur))))
-    (do ((i start (+ i 1))) 
-	((= i end))
-      (outa i (* amp (oscil os))))))
-
-(define (sndclmdoc-simp-2 beg dur freq amp)
-  (let ((os (make-oscil freq))
-	(start (seconds->samples beg))
-	(end (seconds->samples (+ beg dur))))
-    (do ((i start (+ i 1))) 
-	((= i end))
-      (outa i (* amp (oscil os))))))
-
-(definstrument (sndclmdoc-simp-3 beg dur freq amp)
-  (let ((os (make-oscil freq))
-	(start (seconds->samples beg))
-	(end (seconds->samples (+ beg dur))))
-    (do ((i start (+ i 1))) 
-	((= i end))
-      (outa i (* amp (oscil os))))))
+(define sndclmdoc-simp-1 simple-out)
+(define sndclmdoc-simp-2 simple-out)
+(define sndclmdoc-simp-3 simple-out)
 
 (define (sndclmdoc-telephone start telephone-number)
   (let ((touch-tab-1 '(0 697 697 697 770 770 770 852 852 852 941 941 941))
@@ -1686,7 +1633,7 @@
       (let ((zval (env zv))) 
 	(outa i 
 	      (* amp 
-		 (sin (* pi2 zval (* zval zval)))
+		 (sin (* pi2 zval zval zval))
 		 (oscil osc)))))))
 
 (definstrument (sndclmdoc-simple-table dur)
@@ -1760,10 +1707,10 @@
 		      (polynomial cos-coeffs ax))))))))
 
 (definstrument (sndclmdoc-bl-saw start dur frequency order)
-  (let ((norm (if (= order 1) 1.0           ; these peak amps were determined empirically
-		  (if (= order 2) 1.3       ;   actual limit is supposed to be pi/2 (G&R 1.441)
-		      (if (< order 9) 1.7   ;   but Gibbs phenomenon pushes it to 1.851
-			  1.9))))           ;   if order>25, numerical troubles -- use table-lookup
+  (let ((norm (cond ((= order 1) 1.0)      ; these peak amps were determined empirically
+		    ((= order 2) 1.3)      ;   actual limit is supposed to be pi/2 (G&R 1.441)
+		    ((< order 9) 1.7)      ;   but Gibbs phenomenon pushes it to 1.851
+		    (else 1.9)))           ;   if order>25, numerical troubles -- use table-lookup
 	(freqs ()))
     (do ((i 1 (+ i 1)))
 	((> i order))
@@ -1801,9 +1748,9 @@
     (let ((top (* 0.5 range))
 	  (val (if (= ang 0.0) 1.0 (/ (sin ang) ang)))
 	  (new-ang (+ ang frq fm)))
-      (if (> new-ang top)
-	  (set! (gen 0) (- new-ang range))
-	  (set! (gen 0) new-ang))
+      (set! (gen 0) (if (> new-ang top)
+			(- new-ang range)
+			new-ang))
       val)))
 
 (define (sndclmdoc-make-sum-of-odd-sines frequency n)
@@ -1896,12 +1843,15 @@
 
 (definstrument (sndclmdoc-echo beg dur scaler secs file)
   (let ((del (make-delay (seconds->samples secs)))
-	(rd (make-sampler 0 file)))
+	(rd (make-sampler 0 file))
+	(stop (+ beg dur)))
     (do ((i beg (+ i 1)))
-	((= i (+ beg dur)))
+	((= i stop))
       (let ((inval (read-sample rd)))
 	(outa i (+ inval (delay del (* scaler (+ (tap del) inval)))))))))
 
+;  (with-sound () (sndclmdoc-echo 0 60000 .5 1.0 "pistol.snd"))
+
 (define* (sndclmdoc-make-moving-max (size 128))
   (let ((gen (make-delay size)))
     (set! (mus-scaler gen) 0.0)
@@ -1978,18 +1928,13 @@
 
 (definstrument (sndclmdoc-grev beg dur exp-amt file file-beg)
   (let ((exA (make-granulate :expansion exp-amt
-			     :input (make-readin file 0 file-beg -1))))
+			     :input (make-readin file 0 file-beg -1)))
+	(stop (+ beg dur)))
     (do ((i beg (+ i 1)))
-	((= i (+ beg dur)))
+	((= i stop))
       (outa i (granulate exA)))))
 
-(definstrument (sndclmdoc-simple-pvoc beg dur amp size file)
-  (let ((start (seconds->samples beg))
-	(end (seconds->samples (+ beg dur)))
-	(sr (make-phase-vocoder (make-readin file) :fft-size size)))
-    (do ((i start (+ i 1)))
-	((= i end))
-      (outa i (* amp (phase-vocoder sr))))))
+(define sndclmdoc-simple-pvoc sample-pvoc1)
 
 (definstrument (sndclmdoc-asy beg dur freq amp index (r 1.0) (ratio 1.0))
   (let ((st (seconds->samples beg))
@@ -1997,16 +1942,9 @@
 	(asyf (make-asymmetric-fm :r r :ratio ratio :frequency freq)))
     (do ((i st (+ i 1))) 
 	((= i nd))
-      (outa i (* amp (asymmetric-fm asyf index 0.0))))))
+      (outa i (* amp (asymmetric-fm asyf index))))))
 
-(define (sndclmdoc-simple-f2s beg dur amp file)
-  (let ((start (seconds->samples beg))
-	(end (seconds->samples (+ beg dur)))
-	(fil (make-file->sample file)))
-    (do ((i start (+ i 1))
-	 (ctr 0 (+ ctr 1)))
-	((= i end))
-      (outa i (* amp (file->sample fil ctr 0))))))
+(define sndclmdoc-simple-f2s simple-f2s)
 
 (definstrument (sndclmdoc-simple-ina beg dur amp file)
   (let ((start (seconds->samples beg))
@@ -2064,24 +2002,7 @@
 	  (if *reverb* (locsig-reverb-set! loc 0 (* reverb-amount (sqrt dist-scaler))))
 	  (locsig loc i (* (env amp-env) (readin rdA)))))))
 
-(define (sndclmdoc-simple-dloc beg dur freq amp)
-  (let ((os (make-oscil freq))
-	(start (seconds->samples beg))
-	(end (seconds->samples (+ beg dur))))
-    (let ((loc (make-move-sound (list start end 4 0
-				      (make-delay 12) 
-				      (make-env '(0 0 10 1) :duration dur)
-				      #f
-				      (make-vector 4 #f)
-				      (vector (make-env '(0 0 1 1 2 0 3 0 4 0) :duration dur)
-					      (make-env '(0 0 1 0 2 1 3 0 4 0) :duration dur)
-					      (make-env '(0 0 1 0 2 0 3 1 4 0) :duration dur)
-					      (make-env '(0 0 1 0 2 0 3 0 4 1) :duration dur))
-				      #f
-				      (vector 0 1 2 3)))))
-      (do ((i start (+ i 1)))
-	  ((= i end))
-	(move-sound loc i (* amp (oscil os)))))))
+(define sndclmdoc-simple-dloc simple-dloc-4)
 
 (definstrument (when? start-time duration start-freq end-freq grain-file)
   (let ((beg (seconds->samples start-time))
@@ -2210,11 +2131,7 @@
   freq phase fm res)
 
 (define* (sndscm-osc1 gen fm)
-  (let-set! gen 'fm fm)
-  (with-let gen
-    (set! res (sin phase))
-    (set! phase (+ phase freq fm))
-    res))
+  (sndscm-osc gen fm))
 
 (definstrument (sndscm-osc1-fm beg dur freq amp mc-ratio (fm-index 1.0))
   (let ((start (seconds->samples beg))
@@ -2252,11 +2169,7 @@
   freq phase fm res)
 
 (define* (sndscm-osc2 gen fm)
-  (let-set! gen 'fm fm)
-  (with-let gen
-    (set! res (sin phase))
-    (set! phase (+ phase freq fm))
-    res))
+  (sndscm-osc gen fm))
 
 (definstrument (sndscm-osc2-fm beg dur freq amp mc-ratio (fm-index 1.0))
   (let ((start (seconds->samples beg))
@@ -2265,7 +2178,7 @@
 	(modulator (make-sndscm-osc2 (* mc-ratio freq)))
 	(index (hz->radians (* freq mc-ratio fm-index))))
     (if (fneq (mus-frequency carrier) freq)
-	(format #t ";sndscm-osc2 (sclm23.scm) mus-frequency ~A: ~A ~A" (mus-describe carrier) (mus-frequency carrier) freq))
+	(format () ";sndscm-osc2 (sclm23.scm) mus-frequency ~A: ~A ~A" (mus-describe carrier) (mus-frequency carrier) freq))
     (do ((i start (+ i 1)))
 	((= i end))
       (outa i (* amp (sndscm-osc2 carrier (* index (sndscm-osc2 modulator 0.0))))))))
@@ -2415,7 +2328,7 @@
   (with-sound () ; one of JC's favorite demos
     (sndclmdoc-fofins 0 4 270 .2 0.005 730 .6 1090 .3 2440 .1 '(0 0 40 0 75 .2 100 1) 
 		      '(0 0 .5 1 3 .5 10 .2 20 .1 50 .1 60 .2 85 1 100 0))
-    (sndclmdoc-fofins 0 4 (* 6/5 540) .2 0.005 730 .6 1090 .3 2440 .1 '(0 0 40 0 75 .2 100 1) 
+    (sndclmdoc-fofins 0 4 648 .2 0.005 730 .6 1090 .3 2440 .1 '(0 0 40 0 75 .2 100 1) 
 		      '(0 0 .5 .5 3 .25 6 .1 10 .1 50 .1 60 .2 85 1 100 0))
     (sndclmdoc-fofins 0 4 135 .2 0.005 730 .6 1090 .3 2440 .1 '(0 0 40 0 75 .2 100 1) 
 		      '(0 0 1 3 3 1 6 .2 10 .1 50 .1 60 .2 85 1 100 0)))
