@@ -68,7 +68,7 @@
 			  ;; is the linear approximation accurate enough?
 			  ;; are we still over the cutoff limit?
 			  (if (and (> (abs (- yexp yinte)) yerr)
-				   (if ycutoff (> yinte ycutoff) #t))
+				   (or (not ycutoff) (> yinte ycutoff)))
 			      ;; no --> add a breakpoint and recurse right and left
 			      (call-with-values
 				  (lambda () (exp-seg xl yle xint yexp yl yint error))
@@ -515,10 +515,9 @@
 		(set! in-samples (floor (* gr-samples srate-ratio)))
 		
 		;; check for out of bounds condition in in-file pointers
-		(if (> (+ in-start in-samples) last-in-sample)
-		    (set! in-start (- last-in-sample in-samples))
-		    (if (< in-start 0)
-			(set! in-start 0)))
+		(set! in-start (if (> (+ in-start in-samples) last-in-sample)
+				   (- last-in-sample in-samples)
+				   (max in-start 0)))
 		;; reset position of input file reader
 		(set! (mus-location rd) in-start)
 		
