@@ -164,8 +164,7 @@ All mixes sync'd to it are also moved the same number of samples. (hook-remove m
 			   (mix-speed n)
 			   (mix-amp-env n)
 			   (let ((props (mix-properties n)))
-			     (if (and (list? props)
-				      (pair? props))
+			     (if (pair? props)
 				 (format #f "~%  properties: '~A" props)
 				 ""))))
       #t)))
@@ -343,9 +342,9 @@ last end of the mixes in 'mix-list'"))
 	      (let* ((beg-x (+ first-x (* x-scale (- (mix-position m) beg))))
 		     (end-x (+ first-x (* x-scale (- (+ (mix-position m) (framples m)) beg))))
 		     (wenv (window-envelope beg-x end-x overall-amp-env)))
-		(if (null? (mix-amp-env m))
-		    (set! (mix-amp-env m) wenv)
-		    (set! (mix-amp-env m) (multiply-envelopes (mix-amp-env m) wenv)))))
+		(set! (mix-amp-env m) (if (null? (mix-amp-env m)) 
+					  wenv
+					  (multiply-envelopes (mix-amp-env m) wenv)))))
 	    mix-list)))))))
 
 
@@ -399,9 +398,8 @@ last end of the mixes in 'mix-list'"))
 				   mx)))
 		       (set! sorted-mixes (cdr sorted-mixes)))
 		(set! now (+ 1 now))
-		(if (null? sorted-mixes)
-		    #f
-		    0.0)))))))
+		(and (pair? sorted-mixes)
+		     0.0)))))))
 
 
 ;;; -------- pan-mix --------
@@ -445,23 +443,21 @@ panning operation."))
 		     
 		     ;; mono to mono = just scale or envelope
 		     (let ((idx (mix name beg 0 index 0 *with-mix-tags* auto-delete))) ; file start in-chan snd chn ...
-		       (if (and idx (mix? (car idx)))
-			   (let ((id (car idx)))
-			     (set! (mix-amp-env id) (invert-envelope pan))
-			     idx)
-			   #f))
+		       (and idx (mix? (car idx))
+			    (let ((id (car idx)))
+			      (set! (mix-amp-env id) (invert-envelope pan))
+			      idx)))
 		     
 		     ;; mono to stereo
 		     (let ((idx0 (mix name beg 0 index 0 *with-mix-tags* deletion-choice))
 			   (idx1 (mix name beg 0 index 1 *with-mix-tags* end-deletion-choice)))
-		       (if (and idx0 (mix? (car idx0))
-				idx1 (mix? (car idx1)))
-			   (let ((id0 (car idx0))
-				 (id1 (car idx1)))
-			     (set! (mix-amp-env id0) (invert-envelope pan))
-			     (set! (mix-amp-env id1) pan)
-			     (list id0 id1))
-			   #f)))
+		       (and idx0 (mix? (car idx0))
+			    idx1 (mix? (car idx1))
+			    (let ((id0 (car idx0))
+				  (id1 (car idx1)))
+			      (set! (mix-amp-env id0) (invert-envelope pan))
+			      (set! (mix-amp-env id1) pan)
+			      (list id0 id1)))))
 		 
 		 ;; stero input
 		 
@@ -470,14 +466,13 @@ panning operation."))
 		     ;; stereo -> mono => scale or envelope both input chans into the output
 		     (let ((idx0 (mix name beg 0 index 0 *with-mix-tags* deletion-choice))
 			   (idx1 (mix name beg 1 index 0 *with-mix-tags* end-deletion-choice)))
-		       (if (and idx0 (mix? (car idx0))
-				idx1 (mix? (car idx1)))
-			   (let ((id0 (car idx0))
-				 (id1 (car idx1)))
-			     (set! (mix-amp-env id0) (invert-envelope pan))
-			     (set! (mix-amp-env id1) (invert-envelope pan))
-			     (list id0 id1))
-			   #f))
+		       (and idx0 (mix? (car idx0))
+			    idx1 (mix? (car idx1))
+			    (let ((id0 (car idx0))
+				  (id1 (car idx1)))
+			      (set! (mix-amp-env id0) (invert-envelope pan))
+			      (set! (mix-amp-env id1) (invert-envelope pan))
+			      (list id0 id1))))
 		     
 		     ;; stereo -> stereo => incoming chans are treated equally, each panned into outputs
 		     (let ((idx00 (mix name beg 0 index 0 *with-mix-tags* deletion-choice))
@@ -485,20 +480,19 @@ panning operation."))
 			   (idx10 (mix name beg 1 index 0 *with-mix-tags* deletion-choice))
 			   (idx11 (mix name beg 1 index 1 *with-mix-tags* end-deletion-choice)))
 		       
-		       (if (and idx00 (mix? (car idx00))
-				idx01 (mix? (car idx01))
-				idx10 (mix? (car idx10))
-				idx11 (mix? (car idx11)))
-			   (let ((id00 (car idx00))
-				 (id01 (car idx01))
-				 (id10 (car idx10))
-				 (id11 (car idx11)))
-			     (set! (mix-amp-env id00) (invert-envelope pan))
-			     (set! (mix-amp-env id10) (invert-envelope pan))
-			     (set! (mix-amp-env id01) pan)
-			     (set! (mix-amp-env id11) pan)
-			     (list id00 id01 id10 id11))
-			   #f)))))))))))
+		       (and idx00 (mix? (car idx00))
+			    idx01 (mix? (car idx01))
+			    idx10 (mix? (car idx10))
+			    idx11 (mix? (car idx11))
+			    (let ((id00 (car idx00))
+				  (id01 (car idx01))
+				  (id10 (car idx10))
+				  (id11 (car idx11)))
+			      (set! (mix-amp-env id00) (invert-envelope pan))
+			      (set! (mix-amp-env id10) (invert-envelope pan))
+			      (set! (mix-amp-env id01) pan)
+			      (set! (mix-amp-env id11) pan)
+			      (list id00 id01 id10 id11)))))))))))))
 
 
 (define pan-mix-selection 
