@@ -46,12 +46,13 @@
 
 		   'let-ref            (lambda (obj i) (#_vector-ref (obj 'value) i))   ; the implicit case, so 'i can't be the culprit
 		   'vector-length      (lambda (obj) (#_length (obj 'value)))
-		   'vector-append      (make-method #_vector-append (lambda (obj) (obj 'value)))
+		   (reader-cond ((not (provided? 'pure-s7))
+		   'vector-append      (make-method #_vector-append (lambda (obj) (obj 'value)))))
 		   'reverse            (lambda (obj) (#_reverse (obj 'value)))
 		   'sort!              (lambda (obj f) (#_sort! (obj 'value) f))
 		   'make-iterator      (lambda (obj) (#_make-iterator (obj 'value)))
 		   'arity              (lambda (obj) (#_arity (obj 'value)))
-		   'object->string     (lambda* (obj (w #t)) "#<mock-vector-class>")
+		   'object->string     (lambda* (obj (w #t)) (if (eq? w :readable) "*mock-vector*" "#<mock-vector-class>"))
 		   'vector-dimensions  (lambda (obj) (#_vector-dimensions (obj 'value)))
 		   'fill!              (lambda (obj val) (#_fill! (obj 'value) val))
 
@@ -90,6 +91,7 @@
 		   'vector?            (lambda (obj) #t)
 		   'values             (lambda (obj . args) (obj 'value))
 		   'length             (lambda (obj) (#_length (obj 'value)))
+		   'append             (make-method #_append (lambda (obj) (obj 'value)))
 		   'class-name         'mock-vector))))
       
       (define* (make-mock-vector len (init #<unspecified>))
@@ -157,7 +159,6 @@
 	    (inlet 'morally-equal?     (lambda (x y)          (#_morally-equal? (x 'mock-hash-table-table) y))
 		   'hash-table-ref     (lambda (obj key)      (#_hash-table-ref (obj 'mock-hash-table-table) key))
 		   'hash-table-set!    (lambda (obj key val)  (#_hash-table-set! (obj 'mock-hash-table-table) key val))
-		   'hash-table-size    (lambda (obj)          (#_length (obj 'mock-hash-table-table)))
 		   'hash-table-entries (lambda (obj)          (#_hash-table-entries (obj 'mock-hash-table-table)))
 		   'make-iterator      (lambda (obj)          (#_make-iterator (obj 'mock-hash-table-table)))
 
@@ -178,7 +179,7 @@
 		   
 		   'fill!              (lambda (obj val)      (#_fill! (obj 'mock-hash-table-table) val))
 		   'reverse            (lambda (obj)          (#_reverse (obj 'mock-hash-table-table)))
-		   'object->string     (lambda* (obj (w #t))  "#<mock-hash-table-class>")
+		   'object->string     (lambda* (obj (w #t))  (if (eq? w :readable) "*mock-hash-table*" "#<mock-hash-table-class>"))
 		   'arity              (lambda (obj)          (#_arity (obj 'mock-hash-table-table)))
 		   'copy               (lambda* (source dest . args)
 					 (if (mock-hash-table? source)
@@ -192,6 +193,7 @@
 		   'hash-table?        (lambda (obj) #t)
 		   'values             (lambda (obj . args) (obj 'mock-hash-table-table))
 		   'length             (lambda (obj)          (#_length (obj 'mock-hash-table-table)))
+		   'append             (make-method #_append (lambda (obj) (obj 'value)))
 		   'class-name         'mock-hash-table))))
 
       (define* (make-mock-hash-table (len 511))
@@ -260,7 +262,7 @@
 	   (openlet
 	    (inlet 'morally-equal?         (lambda (x y) (#_morally-equal? (x 'value) y))
 		   'reverse                (lambda (obj) (#_reverse (obj 'value)))
-		   'object->string         (lambda* (obj (w #t)) "#<mock-string-class>")
+		   'object->string         (lambda* (obj (w #t)) (if (eq? w :readable) "*mock-string*" "#<mock-string-class>"))
 		   'arity                  (lambda (obj) (#_arity (obj 'value)))
 		   'make-iterator          (lambda (obj) (#_make-iterator (obj 'value)))
 		   'let-ref                (lambda (obj i) (#_string-ref (obj 'value) i))           ; these are the implicit cases
@@ -287,7 +289,7 @@
 		   'getenv                 (lambda (obj) (#_getenv (obj 'value)))
 		   'delete-file            (lambda (obj) (#_delete-file (obj 'value)))
 		   'system                 (lambda* (obj cap) (#_system (obj 'value) cap))
-		   '->bytevector           (lambda (obj) (#_->bytevector (obj 'value))) ; this is in-place! 
+		   '->byte-vector           (lambda (obj) (#_->byte-vector (obj 'value))) ; this is in-place! 
 		   'load                   (lambda* (obj (e (curlet))) (#_load (obj 'value) e))
 		   'eval-string            (lambda* (obj (e (curlet))) (#_eval-string (obj 'value) e))
 		   'char-position          (make-method #_char-position (lambda (obj) (obj 'value)))
@@ -349,6 +351,7 @@
 		   'string?                (lambda (obj) #t)
 		   'values                 (lambda (obj . args) (obj 'value))
 		   'length                 (lambda (obj) (#_string-length (obj 'value)))
+		   'append             (make-method #_append (lambda (obj) (obj 'value)))
 		   'class-name             'mock-string))))
       
       (define* (make-mock-string len (init #\null))
@@ -421,7 +424,7 @@
 		   'char-ci<=?         (make-method #_char-ci<=? (lambda (obj) (obj 'value)))
 		   'char-ci>=?         (make-method #_char-ci>=? (lambda (obj) (obj 'value)))
 		   'string             (make-method #_string (lambda (obj) (obj 'value)))
-		   'object->string     (lambda (obj . args) "#<mock-char-class>")
+		   'object->string     (lambda* (obj (w #t)) (if (eq? w :readable) "*mock-char*" "#<mock-char-class>"))
 		   'arity              (lambda (obj) (#_arity (obj 'value)))
 		   'format             (make-method #_format (lambda (obj) (obj 'value)))
 		   'make-string        (make-method #_make-string (lambda (obj) (obj 'value)))
@@ -444,6 +447,7 @@
 					     (error 'wrong-type-arg "copy: ~S ~S" obj args)))
 		   'char?              (lambda (obj) #t)
 		   'class-name         'mock-char
+		   'length             (lambda (obj) #f)
 		   'values             (lambda (obj . args) (obj 'value))))))
       
       (define (mock-char c) 
@@ -462,15 +466,15 @@
       (curlet))))
 
 #|
-;;; eventually I'll conjure up unichars like (define lambda (bytevector #xce #xbb)) via mock-char,
+;;; eventually I'll conjure up unichars like (define lambda (byte-vector #xce #xbb)) via mock-char,
 ;;;   then combine those into unistring via mock-string
 ;;;
 ;;; (string-length obj)->g_utf8_strlen etc 
-;;;   (g_unichar_isalpha (g_utf8_get_char (bytevector #xce #xbb))) -> #t
-;;;   (g_utf8_strlen (bytevector #xce #xbb #xce #xba) 10) -> 2
-;;;   (g_utf8_normalize (bytevector #xce #xbb #xce #xba) 4 G_NORMALIZE_DEFAULT)
-;;;   but the ones that return gunichar (toupper) currently don't return a bytevector or a string
-;;;   maybe gunichar->bytevector?
+;;;   (g_unichar_isalpha (g_utf8_get_char (byte-vector #xce #xbb))) -> #t
+;;;   (g_utf8_strlen (byte-vector #xce #xbb #xce #xba) 10) -> 2
+;;;   (g_utf8_normalize (byte-vector #xce #xbb #xce #xba) 4 G_NORMALIZE_DEFAULT)
+;;;   but the ones that return gunichar (toupper) currently don't return a byte-vector or a string
+;;;   maybe gunichar->byte-vector?
 ;;;   need glib.scm, or unicode.scm to load the stuff
 |#
 
@@ -486,20 +490,20 @@
 	  (func arg (start 'value))
 	  (if (not (let? start))
 	      (func arg start (end 'value))
-	      (apply func arg (start 'value) end ()))))
+	      (func arg (start 'value) end))))
 
     (define* (range-method-2 func arg1 arg2 start end)
       (if (not end)
 	  (func arg1 arg2 (start 'value))
 	  (if (not (let? start))
 	      (func arg1 arg2 start (end 'value))
-	      (apply func arg1 arg2 (start 'value) end ()))))
+	      (func arg1 arg2 (start 'value) end))))
 
     (let ((mock-number-class
 	   (openlet
 	    (inlet 
 		   'morally-equal?   (lambda (x y) (#_morally-equal? (x 'value) y))
-		   'object->string   (lambda (obj . args) "#<mock-number-class>")
+		   'object->string   (lambda* (obj (w #t)) (if (eq? w :readable) "*mock-number*" "#<mock-number-class>"))
 		   'arity            (lambda (obj) (#_arity (obj 'value)))
 		   'real-part        (lambda (obj) (#_real-part (obj 'value)))
 		   'imag-part        (lambda (obj) (#_imag-part (obj 'value)))
@@ -512,10 +516,11 @@
 		   'negative?        (lambda (obj) (#_negative? (obj 'value)))
 		   'infinite?        (lambda (obj) (#_infinite? (obj 'value)))
 		   'nan?             (lambda (obj) (#_nan? (obj 'value)))
+		   (reader-cond ((not (provided? 'pure-s7))
 		   'make-polar       (make-method #_make-polar (lambda (obj) (obj 'value)))
-		   'make-rectangular (make-method #_make-rectangular (lambda (obj) (obj 'value)))
-		   'make-complex     (make-method #_make-rectangular (lambda (obj) (obj 'value)))
-		   'make-random-state (make-method #_make-random-state (lambda (obj) (obj 'value)))
+		   'make-rectangular (make-method #_complex (lambda (obj) (obj 'value)))))
+		   'complex          (make-method #_complex (lambda (obj) (obj 'value)))
+		   'random-state     (make-method #_random-state (lambda (obj) (obj 'value)))
 		   'magnitude        (lambda (obj) (#_magnitude (obj 'value)))
 		   'angle            (lambda (obj) (#_angle (obj 'value)))
 		   'rationalize      (make-method #_rationalize (lambda (obj) (obj 'value)))
@@ -584,9 +589,9 @@
 		   'make-vector      (make-method #_make-vector (lambda (obj) (obj 'value)))
 		   'make-float-vector(make-method #_make-float-vector (lambda (obj) (obj 'value)))
 		   'make-hash-table  (lambda (ind . args) (apply #_make-hash-table (ind 'value) args))
-		   'make-bytevector  (make-method #_make-bytevector (lambda (obj) (obj 'value)))
+		   'make-byte-vector  (make-method #_make-byte-vector (lambda (obj) (obj 'value)))
 
-		   'bytevector       (make-method #_bytevector (lambda (obj) (obj 'value)))
+		   'byte-vector       (make-method #_byte-vector (lambda (obj) (obj 'value)))
 		   'format           (make-method #_format (lambda (obj) (obj 'value)))
 
 		   'make-string      (lambda (ind . args) 
@@ -836,7 +841,7 @@
 	    (inlet 'morally-equal?   (lambda (x y) (#_morally-equal? (x 'value) y))
 		   'pair-line-number (lambda (obj) (#_pair-line-number (obj 'value)))
 		   'list->string     (lambda (obj) (#_list->string (obj 'value)))
-		   'object->string   (lambda (obj . arg) "#<mock-pair-class>")
+		   'object->string   (lambda* (obj (w #t)) (if (eq? w :readable) "*mock-pair*" "#<mock-pair-class>"))
 		   'list?            (lambda (obj) (#_list? (obj 'value)))
 		   'car              (lambda (obj) (#_car (obj 'value)))
 		   'cdr              (lambda (obj) (#_cdr (obj 'value)))
@@ -870,9 +875,9 @@
 		   'cddddr           (lambda (obj) (#_cddddr (obj 'value)))
 		   'cddadr           (lambda (obj) (#_cddadr (obj 'value)))
 		   'cdddar           (lambda (obj) (#_cdddar (obj 'value)))
+		   'assoc            (lambda (val obj . args) (apply #_assoc val (obj 'value) args))
 		   'assq             (lambda (val obj) (#_assq val (obj 'value)))
 		   'assv             (lambda (val obj) (#_assv val (obj 'value)))
-		   'assoc            (lambda (val obj . args) (apply #_assoc val (obj 'value) args))
 		   'memq             (lambda (val obj) (#_memq val (obj 'value)))
 		   'memv             (lambda (val obj) (#_memv val (obj 'value)))
 		   'member           (lambda (val obj . args) (apply #_member val (obj 'value) args))
@@ -922,6 +927,7 @@
 		   'pair?            (lambda (obj) #t)
 		   'length           (lambda (obj) (#_length (obj 'value)))
 		   'values           (lambda (obj . args) (obj 'value))
+		   'append             (make-method #_append (lambda (obj) (obj 'value)))
 		   'class-name       'mock-pair))))
       
       (define (mock-pair . args)
@@ -974,7 +980,7 @@
 (define *mock-symbol*
   (let ((mock-symbol-class
 	 (openlet
-	  (inlet 'object->string        (lambda (obj . arg) "#<mock-symbol-class>")
+	  (inlet 'object->string        (lambda* (obj (w #t)) (if (eq? w :readable) "*mock-symbol*" "#<mock-symbol-class>"))
 		 'morally-equal?        (lambda (x y) (#_morally-equal? (x 'value) y))
 		 'gensym?               (lambda (obj) (#_gensym? (obj 'value)))
 		 'symbol->string        (lambda (obj) (#_symbol->string (obj 'value)))
@@ -1035,7 +1041,7 @@
 		   'char-ready?         (lambda (obj) (#_char-ready? (obj 'value)))
 		   'port-line-number    (lambda (obj) (#_port-line-number (obj 'value)))
 		   'port-filename       (lambda (obj) (#_port-filename (obj 'value)))
-		   'object->string      (lambda (obj . args) "#<mock-port-class>")
+		   'object->string      (lambda* (obj (w #t)) (if (eq? w :readable) "*mock-port*" "#<mock-port-class>"))
 		   'format              (make-method #_format (lambda (obj) (obj 'value)))
 
 		   'set-current-output-port (lambda (obj) (#_set-current-output-port (obj 'value)))
