@@ -32,11 +32,10 @@
 	 (durs (map car data))
 	 (dur (apply + durs))
 	 (begs (let ((bg beg))
-		 (append (list beg)
-			 (map (lambda (x)
-				(set! bg (+ bg x))
-				bg)
-			      durs))))
+		 (cons beg
+		       (map (lambda (x)
+			      (set! bg (+ bg x)))
+			    durs))))
 	 (beg-samps (map seconds->samples begs)))
 
     (let ((change-times (let* ((len (length beg-samps))
@@ -176,6 +175,7 @@
 	      (noseposition 3)
 
 	      (target-radii (make-float-vector tractlength+8 0.0))
+	      (target-temp (make-float-vector tractlength+8 0.0))
 	      (radii-poles (make-float-vector tractlength+8 0.0))
 	      (radii-pole-gains (make-float-vector tractlength+8 0.0))
 	      (radii (make-float-vector tractlength+8 0.0))
@@ -332,10 +332,14 @@
 		(begin
 		  (if (not new-tract)
 		      (begin
-			(do ((j 0 (+ j 1)))
-			    ((= j tractlength+8))
-			  (float-vector-set! radii j (+ (* (float-vector-ref radii j) (float-vector-ref radii-poles j))
-					     (* (float-vector-ref target-radii j) (float-vector-ref radii-pole-gains j)))))))
+			(float-vector-multiply! radii radii-poles)
+			(copy target-radii target-temp)
+			(float-vector-multiply! target-temp radii-pole-gains)
+			(float-vector-add! radii target-temp)
+			;; (do ((j 0 (+ j 1))) ((= j tractlength+8))
+			;;   (float-vector-set! radii j (+ (* (float-vector-ref radii j) (float-vector-ref radii-poles j))
+			;; 		                   (* (float-vector-ref target-radii j) (float-vector-ref radii-pole-gains j)))))
+			))
 		  ;; set tract shape
 		  (let ((tj 1.0)
 			(tk 0.0))
@@ -343,10 +347,10 @@
 			 (j 1 (+ j 1)))
 			((= j tractlength))
 		      (set! tk tj)
-		      (if (zero? (radii j))
+		      (if (zero? (float-vector-ref radii j))
 			  (set! tj 1e-10)
-			  (set! tj (* (radii k) (radii k))))
-		      (set! (coeffs j) (/ (- tk tj) (+ tk tj)))))
+			  (set! tj (* (float-vector-ref radii k) (float-vector-ref radii k))))
+		      (float-vector-set! coeffs j (/ (- tk tj) (+ tk tj)))))
 
 		  (set! glot-refl-gain (radii tractlength-1))
 		  (set! lip-refl-gain (radii tractlength))
@@ -379,8 +383,7 @@
 		    (let ((temp1 0.0) 
 			  (temp 0.0))
 		      ;; nasal tract (set nasal shape)
-		      (set! temp (- rightradius velumradius))
-		      (if (< temp 0.0) (set! temp 0.0))
+		      (set! temp (max (- rightradius velumradius) 0.0))
 		      (set! alpha1 (* leftradius leftradius))
 		      (set! alpha2 (* temp temp))
 		      (set! alpha3 (* velumradius velumradius))
@@ -416,12 +419,14 @@
 	    
 	    ;; next tract tick
 	    (let ((j 0)
-		  (temp1 0.0)
+		  ;(temp1 0.0)
 		  (temp (dline2 2)))
 	      (set! lt1 (one-pole lp (+ (dline1 2) temp)))
 
 	      (set! (dline2 1) (+ temp (* (coeffs 1) (- glotsamp temp))))
 	      (set! temp (+ glotsamp (- (dline2 1) temp)))
+	      (set! temp (singer-filter 1 noseposition temp dline1 dline2 coeffs))
+#|
 	      (let ((x 0.0))
 		(do ((j 2 (+ j 1))
 		     (k 1 (+ k 1)))
@@ -431,6 +436,7 @@
 		  (set! temp1 temp)
 		  (set! temp (+ (float-vector-ref dline1 k) (- (float-vector-ref dline2 j) x)))
 		  (float-vector-set! dline1 k temp1)))
+|#
 	      (set! j noseposition)	;added
 	      ;;next nasal tick
 	      (let ((plussamp (dline1 (- j 1)))
@@ -448,14 +454,16 @@
 			  (set! time-nose-closed (+ time-nose-closed 1))) ; added 1 bil 17-Apr-11 but didn't test it
 		      ;; nasal tick
 		      (let ((nose-reftemp (+ (* alpha1 plussamp) (* alpha2 minussamp) (* alpha3 (nose2 1)))))
-			(let ((nose-t1 0.0)
+			(let (;(nose-t1 0.0)
 			      (nose-temp 0.0)
 			      (plus-in (* velum-pos (- nose-reftemp (nose2 1)))))
 			  (set! nose-last-minus-refl (- nose-reftemp plussamp))
 			  (set! nose-last-plus-refl (- nose-reftemp minussamp))
 			  (set! nose-reftemp (* (nose-coeffs 1) (- plus-in (nose2 2))))
 			  (set! (nose2 1) (+ (nose2 2) nose-reftemp))
-			  (set! nose-temp (+ plus-in nose-reftemp))
+			  
+			  (set! nose-temp (singer-nose-filter noselength-1 (+ plus-in nose-reftemp) nose1 nose2 nose-coeffs))
+#|
 			  (do ((j 2 (+ j 1))
 			       (k 1 (+ k 1)))
 			      ((= j noselength-1))
@@ -464,6 +472,8 @@
 			    (set! nose-t1 nose-temp)
 			    (set! nose-temp (+ (nose1 k) nose-reftemp))
 			    (set! (nose1 k) nose-t1))
+|#
+
 			  (set! nose-reftemp (* (nose-coeffs noselength-1) (- (nose1 noselength-2) (* nose-last-output 0.25))))
 			  (set! (nose2 noselength-1) (+ (* nose-last-output 0.25) nose-reftemp))
 			  (set! (nose1 noselength-1) (+ (nose1 noselength-2) nose-reftemp))
@@ -472,19 +482,21 @@
 			  (set! nose-filt (nose1 noselength-1))
 			  (set! nose-last-output (* (+ nose-filt nose-filt1) 0.5))))))
 		(set! (dline2 j) nose-last-minus-refl))
-		
 	      (set! (dline1 (- j 1)) temp)
-	      (set! temp nose-last-plus-refl)
 	      
 	      ;; j always starts at 4, goes to 8 so this loop can be unrolled, but doing so doesn't make a big difference
-	      (do ((j (+ noseposition 1) (+ j 1))
-		   (k noseposition (+ k 1)))
-		  ((= j tractlength-1))
-		(let ((x (dline2 (+ j 1))))
-		  (set! (dline2 j) (+ x (* (coeffs j) (- (dline1 k) x))))
+	      (set! temp (singer-filter noseposition tractlength-1 nose-last-plus-refl dline1 dline2 coeffs))
+#|
+	      (let ((x 0.0))
+		(do ((j (+ noseposition 1) (+ j 1))
+		     (k noseposition (+ k 1)))
+		    ((= j tractlength-1))
+		  (set! x (float-vector-ref dline2 (+ j 1)))
+		  (float-vector-set! dline2 j (+ x (* (float-vector-ref coeffs j) (- (float-vector-ref dline1 k) x))))
 		  (set! temp1 temp)
-		  (set! temp (+ (dline1 k) (- (dline2 j) x)))
-		  (set! (dline1 k) temp1)))
+		  (set! temp (+ (float-vector-ref dline1 k) (- (float-vector-ref dline2 j) x)))
+		  (float-vector-set! dline1 k temp1)))
+|#
 
 	      (set! (dline2 tractlength-1) (+ last-lip-refl (* (coeffs tractlength-1) (- (dline1 tractlength-2) last-lip-refl))))
 	      (set! (dline1 tractlength-1) (+ (dline1 tractlength-2) (- (dline2 tractlength-1) last-lip-refl)))
@@ -501,7 +513,8 @@
 	    ))))))
 
 #|
-(with-sound (:statistics #t) (singer 0 .1 (list (list .4 ehh.shp test.glt 523.0 .8 0.0 .01) (list .6 oo.shp test.glt 523.0 .7 .1 .01))))
+(with-sound (:statistics #t) 
+  (singer 0 .1 (list (list .4 ehh.shp test.glt 523.0 .8 0.0 .01) (list .6 oo.shp test.glt 523.0 .7 .1 .01))))
 
 (with-sound (:statistics #t)
 	    (singer 0 .1 (list (list .05 ehh.shp test.glt 523.0 0.8 0.0 .01) 
