@@ -47,7 +47,7 @@
 	 (utargs (let ((arg-names ()))
 		   (for-each
 		    (lambda (a)
-		      (if (not (keyword? a)) ; redundant :optional or something
+		      (if (not (keyword? a))
 			  (if (symbol? a)
 			      (set! arg-names (cons a arg-names))
 			      (set! arg-names (cons (car a) arg-names)))))
@@ -122,7 +122,7 @@
        (set! (locsig-type) *clm-locsig-type*)
        (set! *mus-array-print-length* *clm-array-print-length*)
        (set! *auto-update-interval* 0.0) 
-       (if (equal? clipped 'unset)
+       (if (eq? clipped 'unset)
 	   (if (and (or scaled-by scaled-to)
 		    (member sample-type (list mus-bfloat mus-lfloat mus-bdouble mus-ldouble)))
 	       (set! (mus-clipping) #f)
@@ -132,18 +132,17 @@
 
      (lambda ()
        (if output-to-file
-	   (begin
-	     (if continue-old-file
-		 (begin
-		   (set! *output* (continue-sample->file output-1))
-		   (set! *clm-srate* (mus-sound-srate output-1)) ; "srate" arg shadows the generic func
-		   (let ((ind (find-sound output-1)))
-		     (if (sound? ind)
-			 (close-sound ind))))
-		 (begin
-		   (if (file-exists? output-1) 
-		       (delete-file output-1))
-		   (set! *output* (make-sample->file output-1 channels sample-type header-type comment)))))
+	   (if continue-old-file
+	       (begin
+		 (set! *output* (continue-sample->file output-1))
+		 (set! *clm-srate* (mus-sound-srate output-1)) ; "srate" arg shadows the generic func
+		 (let ((ind (find-sound output-1)))
+		   (if (sound? ind)
+		       (close-sound ind))))
+	       (begin
+		 (if (file-exists? output-1) 
+		     (delete-file output-1))
+		 (set! *output* (make-sample->file output-1 channels sample-type header-type comment))))
 	   (begin
 	     (if (and (not continue-old-file)
 		      (vector? output-1))
@@ -152,18 +151,17 @@
        
        (if reverb
 	   (if reverb-to-file
-	       (begin
-		 (if continue-old-file
-		     (set! *reverb* (continue-sample->file reverb-1))
-		     (begin
-		       (if (file-exists? reverb-1) 
-			   (delete-file reverb-1))
-		       (set! *reverb* (make-sample->file reverb-1 
-							 reverb-channels 
-							 (if (mus-header-writable header-type mus-ldouble)
-							     mus-ldouble
-							     sample-type)
-							 header-type)))))
+	       (if continue-old-file
+		   (set! *reverb* (continue-sample->file reverb-1))
+		   (begin
+		     (if (file-exists? reverb-1) 
+			 (delete-file reverb-1))
+		     (set! *reverb* (make-sample->file reverb-1 
+						       reverb-channels 
+						       (if (mus-header-writable header-type mus-ldouble)
+							   mus-ldouble
+							   sample-type)
+						       header-type))))
 	       (begin
 		 (if (and (not continue-old-file)
 			  (vector? reverb-1))
@@ -189,7 +187,7 @@
 		  ;;   (with-sound () (fm-violin 0 1 440 .1 :amp-env '(0 0 1 1 1 2 3 0)))
 
 		  ;; user might have listener closed, or no listener so...
-		  (format #t ";~%with-sound mus-error: ~{~A~^ ~}~%" (cdr args))
+		  (format () ";~%with-sound mus-error: ~{~A~^ ~}~%" (cdr args))
 
 		  ;; now try to get something to listener, since there may be no stdout
 		  (snd-print (format #f ";~%with-sound mus-error: ~{~A~^ ~}~%" (cdr args)))
@@ -261,35 +259,35 @@
 			cycles)))
 
 	   (if (or scaled-to scaled-by)
-	       (if output-to-file
-		   (let* ((scale-output (or snd-output (open-sound output-1)))
-			  (old-sync (sync scale-output)))
-		     (set! (sync scale-output) (+ (sync-max) 1))          ; make sure scaling doesn't follow sync
-		     (if scaled-to
-			 (scale-to scaled-to scale-output)
-			 (scale-by scaled-by scale-output))
-		     (set! (sync scale-output) old-sync)
-		     (save-sound scale-output)
-		     (if (not to-snd) 
-			 (close-sound scale-output)))
-		   (if (float-vector? output-1)
-		       (if scaled-to
-			   (let ((pk (float-vector-peak output-1)))
-			     (if (> pk 0.0)
-				 (float-vector-scale! output-1 (/ scaled-to pk))))
-			   (float-vector-scale! output-1 scaled-by))
-		       (if (vector? output-1)
-			   (if scaled-to
-			       (let ((pk (maxamp output-1)))
-				 (if (> pk 0.0)
-				     (let ((scl (/ scaled-to pk)))
-				       (do ((i 0 (+ i 1)))
-					   ((= i (length output-1)))
-					 (set! (output-1 i) (* scl (output-1 i)))))))
-			       (do ((i 0 (+ i 1)))
-				   ((= i (length output-1)))
-				 (set! (output-1 i) (* scaled-by (output-1 i)))))))))
-
+	       (cond (output-to-file
+		      (let* ((scale-output (or snd-output (open-sound output-1)))
+			     (old-sync (sync scale-output)))
+			(set! (sync scale-output) (+ (sync-max) 1))          ; make sure scaling doesn't follow sync
+			(if scaled-to
+			    (scale-to scaled-to scale-output)
+			    (scale-by scaled-by scale-output))
+			(set! (sync scale-output) old-sync)
+			(save-sound scale-output)
+			(if (not to-snd) 
+			    (close-sound scale-output))))
+		     ((float-vector? output-1)
+		      (if scaled-to
+			  (let ((pk (float-vector-peak output-1)))
+			    (if (> pk 0.0)
+				(float-vector-scale! output-1 (/ scaled-to pk))))
+			  (float-vector-scale! output-1 scaled-by)))
+		     ((vector? output-1)
+		      (if scaled-to
+			  (let ((pk (maxamp output-1)))
+			    (if (> pk 0.0)
+				(let ((scl (/ scaled-to pk)))
+				  (do ((i 0 (+ i 1)))
+				      ((= i (length output-1)))
+				    (set! (output-1 i) (* scl (output-1 i)))))))
+			  (do ((i 0 (+ i 1)))
+			      ((= i (length output-1)))
+			    (set! (output-1 i) (* scaled-by (output-1 i))))))))
+	   
 	   (if (and play output-to-file)
 	       (if to-snd
 		   (if *clm-player*
@@ -717,7 +715,7 @@
 	  (format fd "      (set! *clm-header-type* ~A)))~%" (mus-header-type->string *clm-header-type*))
 	  (close-appending fd))))))
 
-(if (not (memq ws-save-state (hook-functions after-save-state-hook)))
+(if (not (member ws-save-state (hook-functions after-save-state-hook) eq?))
     (set! (hook-functions after-save-state-hook) (list ws-save-state)))
 
 
@@ -740,10 +738,9 @@ symbol: 'e4 for example.  If 'pythagorean', the frequency calculation uses small
 		 (octave-char (if (and (> (length name) 1)
 				       (char-numeric? (name 1))) 
 				  (name 1)
-				  (if (and (> (length name) 2) 
-					   (char-numeric? (name 2)))
-				      (name 2)
-				      #f)))
+				  (and (> (length name) 2) 
+				       (char-numeric? (name 2))
+				       (name 2))))
 		 (base (modulo (+ 5 (- (char->integer base-char) (char->integer #\a))) 7)) ; c-based (diatonic) octaves
 		 (sign (if (not sign-char) 0 (if (char=? sign-char #\f) -1 1)))
 		 (octave (if octave-char (- (char->integer octave-char) (char->integer #\0)) last-octave))
@@ -780,32 +777,32 @@ symbol: 'e4 for example.  If 'pythagorean', the frequency calculation uses small
 	    ((null? old) nlst)
 	  (if (pair? (car old))
 	      (begin
-		(set-car! (cdr nsym) (caar old))
-		(set-car! nsym (list 'quote (caar old))))
+		(list-set! nsym 1 (caar old))
+		(list-set! nsym 0 (list 'quote (caar old))))
 	      (begin
-		(set-car! (cdr nsym) (car old))
-		(set-car! nsym (list 'quote (car old)))))))))
+		(list-set! nsym 1 (car old))
+		(list-set! nsym 0 (list 'quote (car old)))))))))
 
-  (let* ((name (if (list? struct-name) 
+  (let* ((name (if (pair? struct-name) 
 		   (car struct-name) 
 		   struct-name))
 	 (sname (if (string? name) 
 		    name 
 		    (symbol->string name)))
-	 (wrapper (or (and (list? struct-name)
+	 (wrapper (or (and (pair? struct-name)
 			   (or (and (> (length struct-name) 2)
-				    (equal? (struct-name 1) :make-wrapper)
+				    (eq? (struct-name 1) :make-wrapper)
 				    (struct-name 2))
 			       (and (= (length struct-name) 5)
-				    (equal? (struct-name 3) :make-wrapper)
+				    (eq? (struct-name 3) :make-wrapper)
 				    (struct-name 4))))
 		      (lambda (gen) gen)))
-	 (methods (and (list? struct-name)
+	 (methods (and (pair? struct-name)
 		       (or (and (> (length struct-name) 2)
-				(equal? (struct-name 1) :methods)
+				(eq? (struct-name 1) :methods)
 				(struct-name 2))
 			   (and (= (length struct-name) 5)
-				(equal? (struct-name 3) :methods)
+				(eq? (struct-name 3) :methods)
 				(struct-name 4))))))
     `(begin 
        (define ,(string->symbol (string-append sname "?")) #f)
@@ -821,7 +818,7 @@ symbol: 'e4 for example.  If 'pythagorean', the frequency calculation uses small
 
 	 (set! ,(string->symbol (string-append "make-" sname))
 	       (lambda* ,(map (lambda (n) 
-				(if (list? n) n (list n 0.0)))
+				(if (pair? n) n (list n 0.0)))
 			      fields)
   	         (,wrapper 
 		  (openlet
@@ -887,7 +884,7 @@ symbol: 'e4 for example.  If 'pythagorean', the frequency calculation uses small
 
 
 (define (mix-notelists . notelists)
-  ;; assume the 2nd parameter is the begin time in seconds (the 1st is the instrument name)
+  ;; assume the second parameter is the begin time in seconds (the 1st is the instrument name)
   (sort! 
    (apply append notelists)
    (lambda (note1 note2)
